@@ -1,6 +1,6 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab
 /*
-Gwenview - A simple image viewer for KDE
+Gwenview - A simple image viewer for TDE
 Copyright 2000-2004 Aurlien Gteau
 
 This program is free software; you can redistribute it and/or
@@ -30,7 +30,7 @@ namespace Gwenview {
 
 class BookmarkOwner : public TQObject, public KBookmarkOwner {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	BookmarkOwner(TQWidget* parent);
 
